Module structure

Module structure 

Abstractions over sets with certain structure.

The structure framework used by algebraeon_rings is established here.

Structs

CompositionMorphism
The composition A -> B -> C of two morphisms A -> B and B -> C
EmptySetStructure
EnumeratedFiniteSetStructure
FiniteSetEndofunctions
The set of all endofunctions on a finite set X: functions X → X
Functions
Represent all functions from domain to range
IdentityMorphism
The identity morphism X -> X
PairsStructure
The set of Pairs
SingletonSetStructure
UnorderedPair
UnorderedPairs
The set of unordered Pairs of distinct elements

Traits

BijectiveFunction
BorrowedMorphism
BorrowedSet
BorrowedStructure
CountableSetSignature
Endofunction
A function from a set into itself
Endomorphism
A morphism from an object to itself
EqSignature
FiniteSetSignature
Function
InjectiveFunction
MaybeFiniteSetSignature
MetaType
Morphism
OrdSignature
PartialOrdSignature
Permutation
A permutation is a bijective function from a set to itself
SetSignature
Instances of a type implementing this trait represent a set of elements of type Self::Set with some structure, for example, the structure of a ring.
Signature
ToStringSignature

Derive Macros

CanonicalStructure
Generate a canonical structure type for a type T by decorating it with #[derive(CanonicalStructure)]. Optional additional structure can be generated by adding #[canonical_structure(eq, partial_ord, ord)]. The type must implement Debug and Clone. The optional additional structures may require T to implement further traits. Requires MetaType, Signature, and SetSignature to be in scope. The optional additional structures may require further items to be in scope.