SetSignature

Trait SetSignature 

pub trait SetSignature: Signature {
    type Set: Clone + Debug + Send + Sync;

    // Required method
    fn is_element(&self, x: &Self::Set) -> Result<(), String>;
}
Instances of a type implementing this trait represent a set of elements of type Self::Set with some structure, for example, the structure of a ring.

Required Associated Types

Required Methods

fn is_element(&self, x: &Self::Set) -> Result<(), String>

Some instances of Self::Set may not be valid to represent elements of this set. Return true if x is a valid element and false if not.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors