Module structure

Module structure 

Abstractions over sets with certain structure.

The structure framework used by algebraeon_rings is established here.

Structs

CompositionMorphism
The composition A -> B -> C of two morphisms A -> B and B -> C
EmptySetStructure
EnumeratedFiniteSetStructure
FiniteSetEndofunctions
The set of all endofunctions on a finite set X: functions X → X
Functions
Represent all functions from domain to range
IdentityMorphism
The identity morphism X -> X
Pairs
The set of Pairs
SingletonSetStructure
UnorderedPair
UnorderedPairs
The set of unordered Pairs of distinct elements

Traits

BijectiveFunction
BorrowedMorphism
BorrowedStructure
CountableSetSignature
Endofunction
A function from a set into itself
Endomorphism
A morphism from an object to itself
EqSignature
FiniteSetSignature
Function
InjectiveFunction
MetaType
Morphism
OrdSignature
Permutation
A permutation is a bijective function from a set to itself
SetSignature
Instances of a type implementing this trait represent a set of elements of type Self::Set with some structure, for example, the structure of a ring.
Signature
ToStringSignature

Derive Macros

CanonicalStructure